{ 4I27 DEMO SOFTWARE - VELOCITY MODE TEST PROGRAM FOR 4I27 }

program VELO4I27;
uses CRT;

{$R+}    {Range checking }
{$S+}    {Stack checking }
{$I+}    {I/O checking }

{$I \..\4i27\4I27LOW }                 { include low level 4I27 I/O }
{ program simple test for 4I27 }

const I27Card = $200;                          { default 4I27 location }

var
Motor0 : motor;
Motor1 : motor;
VRPM : real;
foobyte : byte;

procedure InitFilterParameters(var motorx : motor);
begin
  with motorx.Filter do
  begin
    KP := 100;                                   { relativly low gain }
    KI := 100;                                   { integrated error }
    KD := 3000;                                  { some value for damping }
    IL := 10;                                    { low integration limit for now }
  end; {with}
  LoadFilterParameters(motorx);
  UpdateFilter(motorx);
end;

procedure shutdown;
begin
  DisableHbridge(Motor0);
  DisableHBridge(motor1);
  TurnOffMotor(Motor0);
  TurnOffMotor(Motor1);
  Halt(0);
end;

procedure MoveOK(status : byte);
begin
  if status and ExcessivePosMask <> 0 then
  begin
    writeln('Moves stopped do to excessive position error');
    ShutDown;
  end;
end;


begin                                          {main}
  DirectVideo:= false;
  writeln('About to reset the 4I27A');
  if not Reset4I27A(I27Card) then
  begin
    writeln('Couldn''t reset 4I27A card... aborting');
    halt(2);
  end;
  writeln('LM628''S sucessfully reset... proceeding with set-up');
  AssignMotor(Motor0,I27Card,0);               { assign motor 0 to first half of first card }
  AssignMotor(Motor1,I27Card,1);               { assign motor 1 to second half of second card }
  TurnOffMotor(Motor0);
  TurnOffMotor(Motor1);
  EnableHbridge(Motor0);
  EnableHBridge(Motor1);
  DefineHome(Motor0);
  DefineHome(Motor1);
  SetMotionMode(Motor0,PositionMode);          { set up motor 0 for Position mode }
  SetMotionMode(Motor1,PositionMode);          { set up motor 1 for Position mode }
  SetSamplingInterval(Motor0,0);               { set motor 0 for minimum sampling interval }
  SetSamplingInterval(Motor1,0);               { set motor 1 for minimum sampling interval }
  SetClockFrequency(Motor0,8000000);           { 8 Mhz clock }
  SetClockFrequency(Motor1,8000000);           { 8 Mhz clock }
  SetEncoderLines(Motor0,500);                 { just what we happen to have...}
  SetEncoderLines(Motor1,500);                 { just what we happen to have...}
  InitFilterParameters(Motor0);
  InitFilterParameters(Motor1);
  LoadAcceleration(Motor0,1000);
  LoadAcceleration(Motor1,1000);
  LoadPosErrForStop(Motor0,500);
  LoadPosErrForStop(Motor1,500);
  foobyte := PolledXMove(Motor0,100,10000,50000);
  foobyte := PolledXMove(Motor1,100,10000,50000);
  SetMotionMode(Motor0,VelocityMode);          { set up motor 0 for velocity mode }
  SetMotionMode(Motor1,VelocityMode);          { set up motor 1 for velocity mode }
  writeln(' Enter a 0 for speed to quit');
  writeln;
  while 2+2 = 4 do
  begin
    PrintStatus(Motor0);
    PrintStatus(Motor1);
    write('Motor 0 speed in RPM? ');
    Readln(VRPM);
    if VRPM = 0 then ShutDown;
    LoadVelocityInRpm(Motor0,VRPM);
    write('Motor 1 speed in RPM? ');
    Readln(VRPM);
    if VRPM = 0 then ShutDown;
    LoadVelocityInRpm(Motor1,VRPM);
    StartTrajectory(Motor0);
    StartTrajectory(Motor1);
    delay(500);
    MoveOk((ReadLM629Status(Motor0) or ReadLM629Status(Motor1)));
  end; {while}
end.
